@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base qw(DateTime::Format::Natural::Compat);
 
-our $VERSION = '1.26';
+our $VERSION = '1.28';
 
 use constant MORNING   => '08';
 use constant AFTERNOON => '14';
@@ -286,6 +286,19 @@ sub _at
 {
     my $self = shift;
     $self->_register_trace;
+    $self->_at_time(@_);
+}
+
+sub _time
+{
+    my $self = shift;
+    $self->_register_trace;
+    $self->_at_time(@_);
+}
+
+sub _at_time
+{
+    my $self = shift;
     my $opts = pop;
     my $hours = $opts->{hours} || 0;
     my ($time) = @_;
@@ -308,12 +321,6 @@ sub _at
     }
 }
 
-sub _time
-{
-    my $self = shift;
-    $self->_at(@_);
-}
-
 sub _time_full
 {
     my $self = shift;
@@ -450,6 +457,6 @@ Steven Schubiger <schubiger@cpan.org>
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+See L<http://dev.perl.org/licenses/>
 
 =cut
